{ pkgs, ... }:
{
  environment.systemPackages = with pkgs; [
    mc
    nixpkgs-fmt
    tcpdump
  ];
  environment = {
    shellAliases = {
      cp = "cp --reflink=auto";
      diff = "diff --color";
      dmesg = "dmesg --time-format=iso";
      grep = "grep --color";
    };
    variables = {
      HISTCONTROL = "ignoredups:ignorespace";
      HISTFILESIZE = "10000";
      HISTSIZE = "10000";
      TIME_STYLE = "long-iso";
    };
    etc."inputrc".text = ''
      set colored-stats on
      set bell-style none
      set blink-matching-paren on
      set editing-mode vi
      set keyseq-timeout 0
      set show-mode-in-prompt on
      set keymap vi-insert
      set vi-ins-mode-string \1\e[6 q\2
      set vi-cmd-mode-string \1\e[2 q\2
    '';
  };

  programs.neovim = {
    enable = true;
    vimAlias = true;
    defaultEditor = true;
    configure = {
      packages.myPlugin = with pkgs.vimPlugins; {
        #start = [ vim-nix ];
        start = [ vim-lastplace vim-nix nerdtree ];
        #opt = [ YouCompleteMe ];
      };
      customRC = ''
        set nocompatible
        set tabstop=8
        set expandtab
        set shiftwidth=4
        if $TERM == 'linux'
            hi Visual cterm=reverse
        endif
        " au FileType nix exec 'syntax clear nixString'
      '';
    };
  };
  programs.htop.enable = true;
  programs.tmux.enable = true;

  #systemd.services.netdata.serviceConfig = {
  #  ExecStartPre = "${pkgs.tmux}/bin/tmux -S /run/netdata/tmux.socket new-session -s my-session -d";
  #  ExecStopPost = "${pkgs.tmux}/bin/tmux -S /run/netdata/tmux.socket kill-session -t my-session";
  #};

  #systemd.services.phpfpm-nextcloud.serviceConfig = {
  #  #User = "nextcloud";
  #  ExecStartPre = "${pkgs.tmux}/bin/tmux -S /run/phpfpm/tmux.socket new-session -s my-session -d";
  #  ExecStopPost = "${pkgs.tmux}/bin/tmux -S /run/phpfpm/tmux.socket kill-session -t my-session";
  #};
}
